@@ -18,8 +18,8 @@ sys.path.insert(0, os.path.abspath('../../'))
 # -- Project information -----------------------------------------------------
 
 project = 'dustpy'
-copyright = '2020, Sebastian Stammler & Til Birnstiel'
-author = 'Sebastian Stammler & Til Birnstiel'
+copyright = '2020-2022, Sebastian Stammler & Tilman Birnstiel'
+author = 'Sebastian Stammler & Tilman Birnstiel'
 
 
 # -- General configuration ---------------------------------------------------
@@ -55,3 +55,12 @@ exclude_patterns = [
 # a list of builtin themes.
 #
 html_theme = 'sphinx_rtd_theme'
+
+
+# -- Logo --------------------------------------------------------------------
+html_static_path = ['_static']
+html_logo = "_static/logo.png"
+html_theme_options = {
+    'logo_only': True,
+    'display_version': False,
+}
