@@ -286,6 +286,8 @@ subroutine coagulation_parameters(cratRatio, fExcav, fragSlope, m, cstick, cstic
   integer :: ce
   integer :: i
   integer :: j
+  integer :: jmax
+  integer :: jmin
   integer :: k
   integer :: inc
   integer :: p
@@ -370,10 +372,14 @@ subroutine coagulation_parameters(cratRatio, fExcav, fragSlope, m, cstick, cstic
   end do
 
   ! Building modified Podolak coefficients
-  do i=1, Nm
-    do j=1, Nm
+  ! The outer sum does not need to go all the way up to Nm,
+  ! because sticking collisions involving m(Nm) will be outside the mass grid.
+  ! The inner sum will only go to a maximum integer number jmax, such that
+  ! the resulting mass is within the mass grid.
+  do i=1, Nm-1
+    jmax = MIN(Nm-1, INT(LOG10(10.d0**(a*Nm)-10.d0**(a*i))/a))
+    do j=1, jmax
       ! Only if resulting mass inside of grid
-      if(mtot(j, i) .GE. m(Nm) ) cycle
       do k=1, Nm
         cpodmod(k, j, i) = 0.5d0 * kdelta(j, i) * cpod(k, j, i) &
                            & + cpod(k, j, i) * theta( (k-j)*1.d0 - 1.5d0 ) * theta( (j-i)*1.d0 - 0.5d0 ) &
@@ -461,9 +467,8 @@ subroutine coagulation_parameters(cratRatio, fExcav, fragSlope, m, cstick, cstic
     end do
 
     ! Full fragmentation
-    do j=i-p, i
-
-      if(j .LT. 1) cycle
+    jmin = MAX(1, i-p)
+    do j=jmin, i
 
       ! The largest fragment has the mass of the larger collison partner
       klf(j, i) = i
@@ -999,19 +1004,20 @@ subroutine kernel(a, H, Sigma, SigmaFloor, vrel, K, Nr, Nm)
   integer,          intent(in)  :: Nr
   integer,          intent(in)  :: Nm
 
-  integer :: ir
-  integer :: i
-  integer :: j
+  integer          :: ir
+  integer          :: i
+  integer          :: j
+  double precision :: kdelta
 
   ! Initialization
   K(:, :, :) = 0.d0
 
   do ir=2, Nr-1
     do i=1, Nm
-      if(Sigma(ir, i) .lt. SigmaFloor(ir, i)) cycle
+      if(Sigma(ir, i) .LT. SigmaFloor(ir, i)) cycle
       do j=1, i
-        if(Sigma(ir, j) .lt. SigmaFloor(ir, j)) cycle
-        K(ir, j, i) = pi * (a(ir, j) + a(ir, i))**2 * vrel(ir, j, i) &
+        if(Sigma(ir, j) .LT. SigmaFloor(ir, j)) cycle
+        K(ir, j, i) = (1.d0 - 0.5d0*kdelta(j, i)) * pi * (a(ir, j) + a(ir, i))**2 * vrel(ir, j, i) &
           & / sqrt( 2.d0 * pi * ( H(ir, j)**2 + H(ir, i)**2 ) )
       end do
     end do
@@ -1115,6 +1121,7 @@ subroutine s_coag(cstick, cstick_ind, A, eps, klf, krm, phi, Kf, Ks, m, Sigma, S
   integer :: i
   integer :: imax
   integer :: j
+  integer :: jmin
   integer :: k
   integer :: nz
   integer :: p
@@ -1185,8 +1192,8 @@ subroutine s_coag(cstick, cstick_ind, A, eps, klf, krm, phi, Kf, Ks, m, Sigma, S
         end if
       end do
       ! Full fragmentation (only negative terms)
-      do j=i-p, i
-        if(j .LT. 1) cycle
+      jmin = MAX(1, i-p)
+      do j=jmin, i
         S(ir, i) = S(ir, i) - Rf(j, i)
         S(ir, j) = S(ir, j) - Rf(j, i)
       end do
@@ -1431,10 +1438,10 @@ subroutine vrel_brownian_motion(cs, m, T, vrel, Nr, Nm)
 end subroutine vrel_brownian_motion
 
 
-subroutine vrel_cuzzi_ormel_2007(alpha, cs, mump, OmegaK, SigmaGas, &
+subroutine vrel_ormel_cuzzi_2007(alpha, cs, mump, OmegaK, SigmaGas, &
   & St, vrel, Nr, Nm)
   ! Subroutine calculates the relative particle velocities due to turbulent motion
-  ! accourding the prescription of Cuzzi & Ormel (2007).
+  ! accourding the prescription of Ormel & Cuzzi (2007).
   !
   ! Parameters
   ! ----------
@@ -1582,7 +1589,7 @@ subroutine vrel_cuzzi_ormel_2007(alpha, cs, mump, OmegaK, SigmaGas, &
     end do
   end do
 
-end subroutine vrel_cuzzi_ormel_2007
+end subroutine vrel_ormel_cuzzi_2007
 
 
 subroutine vrel_radial_drift(vrad, vrel, Nr, Nm)
